# Copyright (C) 2019 SuperDARN
# Author: Marina Schmidt

"""
Test data sets for DmapWrite
"""
import numpy as np

from collections import OrderedDict

from pydarn import DmapScalar, DmapArray

fitacf_data = [
    OrderedDict([('radar.revision.major',
                  DmapScalar(name='radar.revision.major', value=1, data_type=1,
                             data_type_fmt='c')),
                 ('radar.revision.minor',
                  DmapScalar(name='radar.revision.minor', value=18,
                             data_type=1, data_type_fmt='c')),
                 ('origin.code', DmapScalar(name='origin.code',
                                            value=0, data_type=1,
                                            data_type_fmt='c')),
                 ('origin.time', DmapScalar(name='origin.time',
                                            value='Thu Feb 22 02:39:03 2018',
                                            data_type=9, data_type_fmt='s')),
                 ('origin.command', DmapScalar(name='origin.command',
                                               value='/home/dataman/rst/bin/'
                                               'make_fit -new '
                                               '20180220.0001.00.rkn.rawacf',
                                               data_type=9,
                                               data_type_fmt='s')),
                 ('cp', DmapScalar(name='cp', value=3505, data_type=2,
                                   data_type_fmt='h')),
                 ('stid', DmapScalar(name='stid', value=65,
                                     data_type=2, data_type_fmt='h')),
                 ('time.yr', DmapScalar(name='time.yr', value=2018,
                                        data_type=2, data_type_fmt='h')),
                 ('time.mo', DmapScalar(name='time.mo', value=2, data_type=2,
                                        data_type_fmt='h')),
                 ('time.dy', DmapScalar(name='time.dy', value=20,
                                        data_type=2, data_type_fmt='h')),
                 ('time.hr', DmapScalar(name='time.hr', value=1,
                                        data_type=2, data_type_fmt='h')),
                 ('time.mt', DmapScalar(name='time.mt', value=6, data_type=2,
                                        data_type_fmt='h')),
                 ('time.sc', DmapScalar(name='time.sc', value=28, data_type=2,
                                        data_type_fmt='h')),
                 ('time.us', DmapScalar(name='time.us', value=19887,
                                        data_type=3, data_type_fmt='i')),
                 ('txpow', DmapScalar(name='txpow', value=9000, data_type=2,
                                      data_type_fmt='h')),
                 ('nave', DmapScalar(name='nave', value=29, data_type=2,
                                     data_type_fmt='h')),
                 ('atten', DmapScalar(name='atten', value=0, data_type=2,
                                      data_type_fmt='h')),
                 ('lagfr', DmapScalar(name='lagfr', value=1200,
                                      data_type=2, data_type_fmt='h')),
                 ('smsep', DmapScalar(name='smsep', value=300, data_type=2,
                                      data_type_fmt='h')),
                 ('ercod', DmapScalar(name='ercod', value=0, data_type=2,
                                      data_type_fmt='h')),
                 ('stat.agc', DmapScalar(name='stat.agc', value=0,
                                         data_type=2, data_type_fmt='h')),
                 ('stat.lopwr', DmapScalar(name='stat.lopwr', value=0,
                                           data_type=2, data_type_fmt='h')),
                 ('noise.search', DmapScalar(name='noise.search',
                                             value=12.906009674072266, data_type=4, data_type_fmt='f')),
                 ('noise.mean', DmapScalar(name='noise.mean',
                                           value=397571.90625, data_type=4, data_type_fmt='f')),
                 ('channel', DmapScalar(name='channel', value=1,
                                        data_type=2, data_type_fmt='h')),
                 ('bmnum', DmapScalar(name='bmnum', value=7, data_type=2, data_type_fmt='h')),
                 ('bmazm', DmapScalar(name='bmazm', value=4.090000152587891, data_type=4, data_type_fmt='f')),
                 ('scan', DmapScalar(name='scan', value=0, data_type=2, data_type_fmt='h')),
                 ('offset', DmapScalar(name='offset', value=0, data_type=2, data_type_fmt='h')),
                 ('rxrise', DmapScalar(name='rxrise', value=100, data_type=2, data_type_fmt='h')),
                 ('intt.sc', DmapScalar(name='intt.sc', value=3, data_type=2, data_type_fmt='h')),
                 ('intt.us', DmapScalar(name='intt.us', value=500000, data_type=3, data_type_fmt='i')),
                 ('txpl', DmapScalar(name='txpl', value=300, data_type=2, data_type_fmt='h')),
                 ('mpinc', DmapScalar(name='mpinc', value=2400, data_type=2, data_type_fmt='h')),
                 ('mppul', DmapScalar(name='mppul', value=7, data_type=2, data_type_fmt='h')),
                 ('mplgs', DmapScalar(name='mplgs', value=18, data_type=2, data_type_fmt='h')),
                 ('mplgexs', DmapScalar(name='mplgexs', value=0, data_type=2, data_type_fmt='h')),
                 ('ifmode', DmapScalar(name='ifmode', value=-1, data_type=2, data_type_fmt='h')),
                 ('nrang', DmapScalar(name='nrang', value=100, data_type=2, data_type_fmt='h')),
                 ('frang', DmapScalar(name='frang', value=180, data_type=2, data_type_fmt='h')),
                 ('rsep', DmapScalar(name='rsep', value=45, data_type=2, data_type_fmt='h')),
                 ('xcf', DmapScalar(name='xcf', value=1, data_type=2, data_type_fmt='h')),
                 ('tfreq', DmapScalar(name='tfreq', value=10256, data_type=2, data_type_fmt='h')),
                 ('mxpwr', DmapScalar(name='mxpwr', value=1073741824, data_type=3, data_type_fmt='i')),
                 ('lvmax', DmapScalar(name='lvmax', value=20000, data_type=3, data_type_fmt='i')),
                 ('combf', DmapScalar(name='combf', value='$Id: twofsound.c,v 1.04 2016/11/08 20:00:00 KKrieger Exp $', data_type=9, data_type_fmt='s')),
                 ('fitacf.revision.major', DmapScalar(name='fitacf.revision.major', value=5, data_type=3, data_type_fmt='i')),
                 ('fitacf.revision.minor', DmapScalar(name='fitacf.revision.minor', value=0, data_type=3, data_type_fmt='i')),
                 ('noise.sky', DmapScalar(name='noise.sky', value=16.299999237060547, data_type=4, data_type_fmt='f')),
                 ('noise.lag0', DmapScalar(name='noise.lag0', value=0.0, data_type=4, data_type_fmt='f')),
                 ('noise.vel', DmapScalar(name='noise.vel', value=0.0, data_type=4, data_type_fmt='f')),
                 ('ptab', DmapArray(name='ptab', value=np.array([0, 9, 12, 20, 22, 26, 27], dtype=np.int16), data_type=2, data_type_fmt='h', dimension=1, shape=[7])),
                 ('ltab', DmapArray(name='ltab', value=np.array([0, 0, 26, 27, 20, 22, 9, 12, 22, 26, 22, 27, 20, 26, 20, 27, 12,
                  20, 0, 9, 12, 22, 9, 20, 0, 12, 9, 22, 12, 26, 12, 27, 9, 26,
                  9, 27, 27, 27], dtype=np.int16), data_type=2, data_type_fmt='h', dimension=2, shape=[19, 2])),
                 ('pwr0', DmapArray(name='pwr0', value=np.array([25.482876, 22.258324, -0.7546704, 2.7495077,
                  4.2829385, 10.251047, -1.4400175, -0.7546704,
                  -50., -1.4400175, -6.439859, -9.817387,
                  -3.2569687, -4.5631275, -2.2541587, -1.8280382,
                  -3.2569687, 1.9774551, 8.435729, 13.695346,
                  12.688249, 10.018611, 3.866029, 5.257997,
                  5.780976, 7.207932, 12.105663, 19.4759,
                  21.978638, 20.598166, 22.892414, 21.370316,
                  18.158546, 16.825161, 18.06804, 15.396302,
                  10.903598, 7.156958, 3.2814188, 3.9740682,
                  5.489882, 2.7495077, 0.35785663, 2.7495077,
                  -0.4487027, 0.10528867, -7.8082385, -50.,
                  -50., -3.2569687, -5.4008975, -2.7266836,
                  -1.0838388, 2.3029215, 1.8050935, 1.8050935,
                  -2.2541587, -3.861128, -6.439859, -7.8082385,
                  -1.0838388, -7.8082385, -2.2541587, -7.8082385,
                  -3.861128, -5.4008975, -1.0838388, -3.861128,
                  -5.4008975, -13.670896, -7.8082385, -4.5631275,
                  -3.2569687, 0.8227862, -2.7266836, -1.0838388,
                  -3.2569687, -0.7546704, -6.439859, -2.2541587,
                  -1.0838388, -9.817387, -1.4400175, -5.4008975,
                  -13.670896, -2.7266836, -50., -5.4008975,
                  -7.8082385, -2.2541587, -3.861128, 0.10528867,
                  -5.4008975, -0.4487027, -4.5631275, -1.0838388,
                  -9.817387, -50., -4.5631275, 11.886956],
                  dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[100])),
                 ('slist', DmapArray(name='slist', value=np.array([0, 1, 5, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31,
                  32, 33, 34, 35, 36, 37, 40], dtype=np.int16), data_type=2, data_type_fmt='h', dimension=1, shape=[24])),
                 ('nlag', DmapArray(name='nlag', value=np.array([18, 14, 5, 9, 8, 5, 5, 8, 8, 7, 8, 13, 16, 11, 13, 17, 16,
                  10, 11, 18, 9, 6, 6, 6], dtype=np.int16), data_type=2, data_type_fmt='h', dimension=1, shape=[24])),
                 ('qflg', DmapArray(name='qflg', value=np.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
                  1, 1], np.int8), data_type=1, data_type_fmt='c', dimension=1, shape=[24])),
                 ('gflg', DmapArray(name='gflg', value=np.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                  0, 0], np.int8), data_type=1, data_type_fmt='c', dimension=1, shape=[24])),
                 ('p_l', DmapArray(name='p_l', value=np.array([25.837471, 21.772894, 10.315242, 8.546406, 13.539429,
                  14.268169, 10.585105, 5.629323, 4.9654384, 5.6235294,
                  6.705354, 12.144942, 18.312222, 21.94957, 20.888336,
                  23.049816, 21.096363, 19.696482, 18.23027, 17.981743,
                  15.739749, 11.354882, 7.502067, 6.010397], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('p_l_e', DmapArray(name='p_l_e', value=np.array([0.12540334, 0.30285096, 0.26836973, 0.21962215, 0.44621512,
                  0.9992159, 0.50349855, 0.47247618, 0.4993279, 0.4811757,
                  0.5614341, 0.06773554, 0.41744527, 0.18671621, 0.22014357,
                  0.17500857, 0.20254372, 0.6454112, 0.41737786, 0.12244137,
                  0.19204478, 0.32750002, 0.36852616, 0.2476189], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('p_s', DmapArray(name='p_s', value=np.array([25.391392, 21.279507, 9.8984585, 8.239473, 13.376657,
                  14.4254675, 10.396272, 5.4328876, 4.624584, 5.412306,
                  6.2907987, 11.922243, 17.815878, 21.760286, 20.523682,
                  22.566383, 20.563492, 19.193954, 17.767952, 17.596186,
                  15.391531, 11.110943, 7.2033787, 5.865661], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('p_s_e', DmapArray(name='p_s_e', value=np.array([0.09658687, 0.30153328, 0.5335675, 0.20160311, 0.37454027,
                  0.6018533, 0.32835492, 0.32526138, 0.53839034, 0.43596512,
                  0.58928996, 0.06623815, 0.40487084, 0.14407796, 0.10789531,
                  0.09396324, 0.17330852, 0.35101762, 0.22534896, 0.10679341,
                  0.1470098, 0.23388547, 0.40613198, 0.21845333], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('v', DmapArray(name='v', value=np.array([210.4173, 200.52983, 215.07555, 207.47739, 191.0903, 191.83696,
                  209.5849, 251.1472, 260.30737, 249.832, 239.71947, 256.5703,
                  359.38943, 383.2561, 413.74936, 487.30872, 531.28046, 535.2693,
                  504.72272, 440.33603, 368.79492, 319.20898, 250.16727, 114.16911],
                  dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('v_e', DmapArray(name='v_e', value=np.array([3.9786088, 7.012827, -33.193398, -4.463376,
                  -1.6737736, -6.0411186, -4.7577586, 8.152869,
                  11.382911, -6.635872, -6.3119335, 2.0531669,
                  2.5595334, -0.89524144, 2.163332, 1.1770849,
                  1.885144, 2.986912, 2.7908595, 1.8639158,
                  -3.4462364, -3.4294195, -6.1686172, -4.4189973],
                  dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('w_l', DmapArray(name='w_l', value=np.array([83.878746, 99.753044, 153.06863, 55.7092, 31.258623,
                  32.607876, 77.80331, 73.54085, 89.46751, 36.6982,
                  95.70889, 37.204212, 76.04568, 28.654127, 84.78225,
                  117.6946, 138.9422, 94.33889, 81.74415, 66.54825,
                  66.807594, 68.87775, 57.30965, 30.900507], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('w_l_e', DmapArray(name='w_l_e', value=np.array([7.109349, 19.477041, 18.231478, 10.996366, 20.184359,
                  71.433754, 30.116459, 29.81509, 30.544685, 25.828869,
                  36.886547, 3.3912168, 20.679068, 7.6170983, 12.121777,
                  12.003044, 15.073383, 31.873648, 21.10902, 6.5249286,
                  9.458526, 16.720922, 17.051199, 10.658608], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('w_s', DmapArray(name='w_s', value=np.array([167.82883, 173.47348, 233.15923, 135.62325, 101.29973,
                  184.86955, 184.36272, 186.975, 180.45955, 107.827995,
                  179.98326, 109.67403, 141.13757, 91.63864, 177.247,
                  221.76321, 244.4691, 184.0788, 166.55692, 145.02649,
                  147.4922, 154.32692, 124.689125, 96.998505], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('w_s_e', DmapArray(name='w_s_e', value=np.array([6.9921713, 22.92682, 33.29458, 15.932335, 34.298935,
                  73.223854, 24.629501, 27.916792, 44.0334, 49.67091,
                  52.318226, 6.459716, 27.34461, 12.055722, 7.242446,
                  7.41231, 14.243067, 19.954693, 14.040812, 8.09781,
                  9.85989, 14.963779, 26.252836, 17.50076], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('sd_l', DmapArray(name='sd_l', value=np.array([0.07678557, 0.19544871, 0.12019609, 0.08737351, 0.16077198,
                  0.25815094, 0.17776884, 0.19282965, 0.23275045, 0.179218,
                  0.2708179, 0.03100524, 0.26058298, 0.0716453, 0.11563717,
                  0.10870428, 0.12833513, 0.24831082, 0.17849617, 0.07292715,
                  0.0802837, 0.12825055, 0.14628929, 0.0864696], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('sd_s', DmapArray(name='sd_s', value=np.array([0.07562572, 0.23361373, 0.25926307, 0.0995465, 0.1628513,
                  0.2174241, 0.13478918, 0.16230391, 0.27622813, 0.1907096,
                  0.3194423, 0.03898079, 0.29843497, 0.07119729, 0.07097206,
                  0.07450401, 0.1361929, 0.1901988, 0.13250129, 0.08141139,
                  0.07634614, 0.10642347, 0.18352786, 0.08909834], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('sd_phi', DmapArray(name='sd_phi', value=np.array([0.14121413, 0.19921292, 0.55738163, 0.12504993, 0.04891057,
                  0.08948292, 0.0851823, 0.17357136, 0.25275612, 0.15320578,
                  0.13208257, 0.06842917, 0.09970863, 0.0336997, 0.06815802,
                  0.03461095, 0.04988815, 0.09344769, 0.08783954, 0.06965055,
                  0.09880196, 0.07864764, 0.15442486, 0.11673748], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('x_qflg', DmapArray(name='x_qflg', value=np.array([1, 1, 1, 1, 1, 1, 4, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
                  1, 1], np.int8), data_type=1, data_type_fmt='c', dimension=1, shape=[24])),
                 ('x_gflg', DmapArray(name='x_gflg', value=np.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                  0, 0], np.int8), data_type=1, data_type_fmt='c', dimension=1, shape=[24])),
                 ('x_p_l', DmapArray(name='x_p_l', value=np.array([27.714064, 22.498621, 14.773344, 8.674485, 14.955762,
                  15.4034815, -50., 5.7427235, 2.2186325, 6.577615,
                  7.4266825, 11.749854, 17.635168, 21.933393, 19.68564,
                  22.835394, 21.13682, 19.438774, 17.741188, 18.237307,
                  15.968641, 11.728345, 6.3010383, 5.852917], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('x_p_l_e', DmapArray(name='x_p_l_e', value=np.array([0.3816435, 0.30511376, 0.24965997, 0.5391254, 0.5861169,
                  1.1781335, 0., 0.49218217, 0.8023588, 0.4629429,
                  0.72451323, 0.44120732, 0.4393533, 0.16481791, 0.2829396,
                  0.17049426, 0.19537082, 0.57809436, 0.3204774, 0.13701357,
                  0.11459232, 0.37732843, 0.7576905, 1.1598037], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('x_p_s', DmapArray(name='x_p_s', value=np.array([27.449762, 22.105358, 14.306933, 8.666591, 14.804492,
                  15.497991, -50., 5.655672, 2.4488459, 6.424003,
                  7.2596107, 11.468881, 17.28569, 21.696486, 19.30399,
                  22.296707, 20.5503, 18.966454, 17.411947, 17.832598,
                  15.587591, 11.398707, 6.30129, 6.5174475], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('x_p_s_e', DmapArray(name='x_p_s_e', value=np.array([0.2303024, 0.29945874, 0.54957503, 0.3789636, 0.38615614,
                  0.66818225, 0., 0.38068995, 0.7358919, 0.40694228,
                  0.8647962, 0.33124682, 0.4084412, 0.11354841, 0.32705876,
                  0.06472139, 0.1707116, 0.31454512, 0.2021999, 0.12369697,
                  0.16541561, 0.31807196, 0.6204366, 0.8847257], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('x_v', DmapArray(name='x_v', value=np.array([281.97443, 223.11514, 221.63034, 197.44917, 188.27458,
                  197.8503, 0., 247.33612, 210.60432, 305.89215,
                  247.01543, 258.8349, 393.53342, 397.38754, 429.03232,
                  501.37967, 551.29156, 536.06995, 514.34, 446.62015,
                  366.91202, 322.7745, 242.80046, 106.463936], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('x_v_e', DmapArray(name='x_v_e', value=np.array([26.394007, 36.618652, 70.31171, 63.333218, 63.895203,
                  144.26108, 0., 93.20139, 122.45326, 75.738655,
                  229.64532, 56.638374, 65.40975, 55.844543, 70.64021,
                  58.674725, 80.664215, 70.150505, 48.79837, 39.537964,
                  73.53863, 119.14103, 78.47234, 83.04331], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('x_w_l', DmapArray(name='x_w_l', value=np.array([57.389225, 57.69733, 126.23592, 30.237602, 47.113304,
                  58.984756, 0., 38.26878, -48.92362, 19.931614,
                  260.41132, 42.224785, 44.766846, 36.143654, 82.68581,
                  126.724434, 156.66393, 87.717186, 56.204193, 71.46811,
                  70.74363, 101.99929, 0.3202165, -26.054714], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('x_w_l_e', DmapArray(name='x_w_l_e', value=np.array([19.230837, 16.294899, 15.168548, 26.129055, 31.24727,
                  90.87292, 0., 27.570515, 40.068256, 25.276037,
                  97.13555, 23.300837, 21.864376, 7.1030188, 13.769096,
                  12.655528, 16.46391, 28.089544, 14.207863, 7.4522157,
                  5.6516047, 22.447966, 31.974655, 40.390575], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('x_w_s', DmapArray(name='x_w_s', value=np.array([145.92664, 116.73225, 199.16847, 121.673805, 142.27568,
                  233.33675, 0., 133.75916, -137.55725, 68.61652,
                  418.2039, 112.81758, 101.29247, 104.3191, 157.19446,
                  227.0272, 260.67654, 176.15086, 133.56267, 151.0875,
                  148.78038, 190.15187, 11.559557, -22.508564], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('x_w_s_e', DmapArray(name='x_w_s_e', value=np.array([16.604748, 25.460632, 33.55762, 33.030075, 32.192673,
                  73.7608, 0., 39.169834, 67.15969, 71.89186,
                  104.778595, 32.13061, 39.87153, 9.046842, 18.910078,
                  5.3034163, 15.238569, 18.197418, 12.990403, 9.309874,
                  10.952014, 19.948631, 379.5419, 249.17317], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('phi0', DmapArray(name='phi0', value=np.array([1.399587, 1.9543043, -0.7224908, 2.0916905, 2.0584743,
                  2.0382516, 0., 2.0375803, 2.335712, 1.8491666,
                  2.056926, 2.4982245, -2.944642, -2.7769294, -2.580205,
                  -2.5932343, -2.6255465, -2.6566849, -2.5612776, -2.547088,
                  -2.4405823, -2.566693, -2.4519978, -2.4570632], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('phi0_e', DmapArray(name='phi0_e', value=np.array([0.24121854, 0.31576076, 0.5329399, 0.6017877, 0.5519327,
                  0.8613009, 0., 0.7662122, 1.1292348, 0.63882476,
                  0.9944896, 0.49388707, 0.6052921, 0.59674376, 0.6684763,
                  0.36402082, 0.44081196, 0.6648605, 0.5068969, 0.3347635,
                  0.68666506, 0.9222519, 0.85634404, 1.0981326], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('elv', DmapArray(name='elv', value=np.array([35.70254, 38.16125, 24.39799, 38.74954, 38.608,
                  38.521618, 0., 38.518745, 39.77631, 37.705807,
                  38.601395, 40.447994, 43.784958, 44.426586, 4.395376,
                  3.9164848, 2.3389988, 44.882126, 5.0102973, 5.4258823,
                  7.875571, 4.8423176, 7.650461, 7.5484366], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('elv_low', DmapArray(name='elv_low', value=np.array([36.789043, 39.50229, 27.634506, 41.24298, 40.90631, 42.068584,
                  0., 41.6866, 44.269234, 40.405975, 42.668644, 42.435135,
                  9.646016, 11.912934, 14.987502, 11.262804, 11.854093, 14.139045,
                  13.439983, 11.490857, 16.53503, 17.530523, 17.956919, 19.9007],
                  dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('elv_high', DmapArray(name='elv_high', value=np.array([34.58656, 36.778984, 20.695374, 36.112648, 36.187763, 34.67364,
                  0., 35.113194, 34.811623, 34.829647, 34.133892, 38.376377,
                  41.403374, 42.10815, 42.60216, 43.7364, 43.314564, 42.314747,
                  43.307514, 44.02605, 43.077705, 41.648342, 42.366947, 41.382183],
                  dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('x_sd_l', DmapArray(name='x_sd_l', value=np.array([0.1756741, 0.19235736, 0.10428195, 0.18796304, 0.21322642,
                  0.3125638, 0., 0.16106041, 0.20110454, 0.17890598,
                  0.32863578, 0.18474424, 0.23959318, 0.06693348, 0.14577192,
                  0.10317358, 0.12183417, 0.22132954, 0.12958534, 0.08301932,
                  0.04934168, 0.16750264, 0.24611072, 0.21731581], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('x_sd_s', DmapArray(name='x_sd_s', value=np.array([0.14324568, 0.22587489, 0.25398815, 0.16678365, 0.1868976,
                  0.2501515, 0., 0.14932126, 0.21152444, 0.18535602,
                  0.40078032, 0.1863737, 0.26176426, 0.06100182, 0.1913554,
                  0.0508818, 0.13343154, 0.16805556, 0.10831408, 0.09524555,
                  0.08642831, 0.16105707, 0.24610558, 0.2311904], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[24])),
                 ('x_sd_phi',
                  DmapArray(name='x_sd_phi',
                            value=np.array([0.4822196, 0.86454874, 0.9667692,
                                            0.91119283, 0.8720215,
                                            0.9923923, 0., 1.0889208,
                                            1.2291979, 1.0721695,
                                            2.2484603, 0.89813197,
                                            1.4335402, 1.0524737, 1.4957206,
                                            0.9566858, 1.1938425, 1.1054916,
                                            0.89014846, 0.88092315,
                                            1.284067, 1.7780174, 1.2080121,
                                            0.8936057], dtype=np.float32),
                            data_type=4, data_type_fmt='f', dimension=1,
                            shape=[24]))]),
    OrderedDict([('radar.revision.major', DmapScalar(name='radar.revision.major', value=1, data_type=1, data_type_fmt='c')),
                 ('radar.revision.minor', DmapScalar(name='radar.revision.minor', value=18, data_type=1, data_type_fmt='c')),
                 ('origin.code', DmapScalar(name='origin.code', value=0, data_type=1, data_type_fmt='c')),
                 ('origin.time', DmapScalar(name='origin.time', value='Thu Feb 22 02:39:17 2018', data_type=9, data_type_fmt='s')),
                 ('origin.command', DmapScalar(name='origin.command', value='/home/dataman/rst/bin/make_fit -new 20180220.0201.00.rkn.rawacf', data_type=9, data_type_fmt='s')),
                 ('cp', DmapScalar(name='cp', value=3505, data_type=2, data_type_fmt='h')),
                 ('stid', DmapScalar(name='stid', value=65, data_type=2, data_type_fmt='h')),
                 ('time.yr', DmapScalar(name='time.yr', value=2018, data_type=2, data_type_fmt='h')),
                 ('time.mo', DmapScalar(name='time.mo', value=2, data_type=2, data_type_fmt='h')),
                 ('time.dy', DmapScalar(name='time.dy', value=20, data_type=2, data_type_fmt='h')),
                 ('time.hr', DmapScalar(name='time.hr', value=2, data_type=2, data_type_fmt='h')),
                 ('time.mt', DmapScalar(name='time.mt', value=43, data_type=2, data_type_fmt='h')),
                 ('time.sc', DmapScalar(name='time.sc', value=52, data_type=2, data_type_fmt='h')),
                 ('time.us', DmapScalar(name='time.us', value=443331, data_type=3, data_type_fmt='i')),
                 ('txpow', DmapScalar(name='txpow', value=9000, data_type=2, data_type_fmt='h')),
                 ('nave', DmapScalar(name='nave', value=29, data_type=2, data_type_fmt='h')),
                 ('atten', DmapScalar(name='atten', value=0, data_type=2, data_type_fmt='h')),
                 ('lagfr', DmapScalar(name='lagfr', value=1200, data_type=2, data_type_fmt='h')),
                 ('smsep', DmapScalar(name='smsep', value=300, data_type=2, data_type_fmt='h')),
                 ('ercod', DmapScalar(name='ercod', value=0, data_type=2, data_type_fmt='h')),
                 ('stat.agc', DmapScalar(name='stat.agc', value=0, data_type=2, data_type_fmt='h')),
                 ('stat.lopwr', DmapScalar(name='stat.lopwr', value=0, data_type=2, data_type_fmt='h')),
                 ('noise.search', DmapScalar(name='noise.search', value=12.143050193786621, data_type=4, data_type_fmt='f')),
                 ('noise.mean', DmapScalar(name='noise.mean', value=474406.125, data_type=4, data_type_fmt='f')),
                 ('channel', DmapScalar(name='channel', value=2, data_type=2, data_type_fmt='h')),
                 ('bmnum', DmapScalar(name='bmnum', value=0, data_type=2, data_type_fmt='h')),
                 ('bmazm', DmapScalar(name='bmazm', value=-18.59000015258789, data_type=4, data_type_fmt='f')),
                 ('scan', DmapScalar(name='scan', value=0, data_type=2, data_type_fmt='h')),
                 ('offset', DmapScalar(name='offset', value=0, data_type=2, data_type_fmt='h')),
                 ('rxrise', DmapScalar(name='rxrise', value=100, data_type=2, data_type_fmt='h')),
                 ('intt.sc', DmapScalar(name='intt.sc', value=3, data_type=2, data_type_fmt='h')),
                 ('intt.us', DmapScalar(name='intt.us', value=500000, data_type=3, data_type_fmt='i')),
                 ('txpl', DmapScalar(name='txpl', value=300, data_type=2, data_type_fmt='h')),
                 ('mpinc', DmapScalar(name='mpinc', value=2400, data_type=2, data_type_fmt='h')),
                 ('mppul', DmapScalar(name='mppul', value=7, data_type=2, data_type_fmt='h')),
                 ('mplgs', DmapScalar(name='mplgs', value=18, data_type=2, data_type_fmt='h')),
                 ('mplgexs', DmapScalar(name='mplgexs', value=0, data_type=2, data_type_fmt='h')),
                 ('ifmode', DmapScalar(name='ifmode', value=-1, data_type=2, data_type_fmt='h')),
                 ('nrang', DmapScalar(name='nrang', value=100, data_type=2, data_type_fmt='h')),
                 ('frang', DmapScalar(name='frang', value=180, data_type=2, data_type_fmt='h')),
                 ('rsep', DmapScalar(name='rsep', value=45, data_type=2, data_type_fmt='h')),
                 ('xcf', DmapScalar(name='xcf', value=1, data_type=2, data_type_fmt='h')),
                 ('tfreq', DmapScalar(name='tfreq', value=12423, data_type=2, data_type_fmt='h')),
                 ('mxpwr', DmapScalar(name='mxpwr', value=1073741824, data_type=3, data_type_fmt='i')),
                 ('lvmax', DmapScalar(name='lvmax', value=20000, data_type=3, data_type_fmt='i')),
                 ('combf', DmapScalar(name='combf', value='$Id: twofsound.c,v 1.04 2016/11/08 20:00:00 KKrieger Exp $', data_type=9, data_type_fmt='s')),
                 ('fitacf.revision.major', DmapScalar(name='fitacf.revision.major', value=5, data_type=3, data_type_fmt='i')),
                 ('fitacf.revision.minor', DmapScalar(name='fitacf.revision.minor', value=0, data_type=3, data_type_fmt='i')),
                 ('noise.sky', DmapScalar(name='noise.sky', value=15.399999618530273, data_type=4, data_type_fmt='f')),
                 ('noise.lag0', DmapScalar(name='noise.lag0', value=0.0, data_type=4, data_type_fmt='f')),
                 ('noise.vel', DmapScalar(name='noise.vel', value=0.0, data_type=4, data_type_fmt='f')),
                 ('ptab', DmapArray(name='ptab', value=np.array([0, 9, 12, 20, 22, 26, 27], dtype=np.int16), data_type=2, data_type_fmt='h', dimension=1, shape=[7])),
                 ('ltab', DmapArray(name='ltab', value=np.array([0, 0, 26, 27, 20, 22, 9, 12, 22, 26, 22, 27, 20, 26, 20, 27, 12,
                  20, 0, 9, 12, 22, 9, 20, 0, 12, 9, 22, 12, 26, 12, 27, 9, 26,
                  9, 27, 27, 27], dtype=np.int16), data_type=2, data_type_fmt='h', dimension=2, shape=[19, 2])),
                 ('pwr0', DmapArray(name='pwr0', value=np.array([3.3881855, 1.263465, 8.791779, 14.575084,
                  15.58802, 19.181938, 15.222579, 10.763519,
                  7.929372, 8.019291, 0.32587367, 0.32587367,
                  -3.0670712, -3.6797678, 0.32587367, 4.210053,
                  2.83771, 0.05603877, -4.3933268, 0.8199222,
                  2.034144, 1.4693303, -0.23167865, -6.3121824,
                  -3.0670712, -14.093695, -4.3933268, -6.3121824,
                  -7.725474, -5.2476287, -9.834007, -7.725474,
                  -0.23167865, 4.1017447, 1.8539128, 2.6884532,
                  2.83771, 1.8539128, 4.5196576, 0.32587367,
                  1.8539128, 2.373609, 3.8766713, 2.83771,
                  -0.5398181, -3.6797678, -1.6221485, -3.0670712,
                  -2.5302227, -5.2476287, -14.093695, -6.3121824,
                  -14.093695, -4.3933268, -9.834007, -2.0524948,
                  -9.834007, -50., -4.3933268, -14.093695,
                  -2.0524948, -9.834007, -7.725474, -6.3121824,
                  -7.725474, -4.3933268, -7.725474, -3.6797678,
                  -7.725474, -14.093695, -9.834007, -4.3933268,
                  -50., -3.0670712, -7.725474, -9.834007,
                  -0.5398181, -4.3933268, -50., -14.093695,
                  -9.834007, -6.3121824, -50., -5.2476287,
                  -6.3121824, -9.834007, -1.6221485, -4.3933268,
                  -2.0524948, -2.5302227, -3.6797678, -4.3933268,
                  -6.3121824, -14.093695, -5.2476287, -50.,
                  -3.6797678, -3.6797678, -4.3933268, 8.678576],
                  dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[100])),
                 ('slist', DmapArray(name='slist', value=np.array([0, 4, 5, 6, 7, 8, 9, 15, 36, 38, 41, 43], dtype=np.int16), data_type=2, data_type_fmt='h', dimension=1, shape=[12])),
                 ('nlag', DmapArray(name='nlag', value=np.array([6, 11, 5, 13, 10, 15, 14, 8, 6, 5, 6, 6], dtype=np.int16), data_type=2, data_type_fmt='h', dimension=1, shape=[12])),
                 ('qflg', DmapArray(name='qflg', value=np.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], np.int8), data_type=1, data_type_fmt='c', dimension=1, shape=[12])),
                 ('gflg', DmapArray(name='gflg', value=np.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], np.int8), data_type=1, data_type_fmt='c', dimension=1, shape=[12])),
                 ('p_l', DmapArray(name='p_l', value=np.array([3.5497692, 15.219805, 19.058012, 14.784413, 10.281843,
                  6.939279, 7.670358, 5.8116884, 3.3686848, 4.8680186,
                  2.7661672, 4.165058], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('p_l_e', DmapArray(name='p_l_e', value=np.array([0.4204376, 0.3505618, 0.3253947, 0.36781773, 0.5577228,
                  0.4022448, 0.25193536, 0.60134286, np.inf, np.inf,
                  0.3410064, 0.47262317], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('p_s', DmapArray(name='p_s', value=np.array([3.210243, 14.588972, 18.60333, 14.040471, 9.683641,
                  6.422316, 7.34638, 5.332991, 3.1633725, 4.8680186,
                  2.541066, 3.9029372], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('p_s_e', DmapArray(name='p_s_e', value=np.array([0.6084755, 0.43360505, 0.6442308, 0.3823753, 0.635267,
                  0.4464058, 0.24834335, 0.43611935, np.inf, np.inf,
                  0.44715923, 0.26666653], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('v', DmapArray(name='v', value=np.array([-104.39679, -342.97348, -285.34897, -251.2897, -184.85536,
                  -305.7072, -312.8774, -113.41999, -207.84285, -233.70502,
                  -256.89438, -245.66766], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('v_e', DmapArray(name='v_e', value=np.array([-9.114674, -8.124575, -31.326744, -9.795714, 16.097227,
                  7.834782, -3.636186, 23.887688, -33.519596, -19.189497,
                  18.326107, 10.769966], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('w_l', DmapArray(name='w_l', value=np.array([115.201546, 107.62786, 464.26938, 114.610535, 185.66608,
                  82.26722, 39.18749, 124.76609, 106.327774, 560.7009,
                  75.70222, 95.38054], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('w_l_e', DmapArray(name='w_l_e', value=np.array([26.75211, 18.443213, 64.782196, 20.40742, 46.594242, 19.587702,
                  10.786126, 43.510963, np.inf, np.inf, 21.613358, 27.325829],
                  dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('w_s', DmapArray(name='w_s', value=np.array([200.20377, 154.28627, 551.15564, 160.30864, 248.93988, 128.84338,
                  89.82784, 213.72595, 235.80905, 475.4645, 166.03622, 200.64261],
                  dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('w_s_e', DmapArray(name='w_s_e', value=np.array([41.936104, 23.068935, 96.47285, 21.24448, 49.238255, 25.204145,
                  18.666155, 30.81735, np.inf, np.inf, 37.603992, 17.433638],
                  dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('sd_l', DmapArray(name='sd_l', value=np.array([0.17549379, 0.22083001, 0.18090267, 0.2481737, 0.355894,
                  0.2719005, 0.14545113, 0.2891923, np.inf, np.inf,
                  0.12042583, 0.17959179], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('sd_s', DmapArray(name='sd_s', value=np.array([0.2729755, 0.31548944, 0.38025123, 0.31500262, 0.45055687,
                  0.34171918, 0.17246605, 0.25702748, np.inf, np.inf,
                  0.17277695, 0.1193686], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('sd_phi', DmapArray(name='sd_phi', value=np.array([0.18365021, 0.25823486, 0.1979715, 0.33172324, 0.34346697,
                  0.31707346, 0.14914487, 0.49632668, 0.58580476, 0.2802783,
                  0.38193268, 0.21990536], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('x_qflg', DmapArray(name='x_qflg', value=np.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1], np.int8), data_type=1, data_type_fmt='c', dimension=1, shape=[12])),
                 ('x_gflg', DmapArray(name='x_gflg', value=np.array([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], np.int8), data_type=1, data_type_fmt='c', dimension=1, shape=[12])),
                 ('x_p_l', DmapArray(name='x_p_l', value=np.array([0.89324456, 16.801666, 18.62557, 14.448944, 9.817669,
                  6.69979, 6.4301286, 6.5051303, 2.654736, 3.9768033,
                  -0.6938298, 3.1957011], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('x_p_l_e', DmapArray(name='x_p_l_e', value=np.array([1.05346, 0.373323, 0.42180446, 0.6168531, 0.40609515,
                  0.5390204, 0.43419337, 1.3868219, 0.95508665, 0.30156177,
                  0.30076468, 0.8342631], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('x_p_s', DmapArray(name='x_p_s', value=np.array([0.967382, 16.105404, 18.05176, 14.224932, 9.380045,
                  6.254807, 6.426912, 6.212974, 2.5523796, 3.631779,
                  -0.75107485, 3.1319592], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('x_p_s_e', DmapArray(name='x_p_s_e', value=np.array([0.8583297, 0.4714994, 0.5957066, 0.57107013, 0.62998855,
                  0.5534169, 0.33480978, 0.977634, 0.63024247, 0.5643229,
                  0.30037746, 0.5892786], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('x_v', DmapArray(name='x_v', value=np.array([-119.49145, -328.7751, -298.08453, -211.84265, -348.66498,
                  -433.93707, -303.01135, -120.90141, -244.6152, -355.99246,
                  -313.2477, -246.9257], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('x_v_e', DmapArray(name='x_v_e', value=np.array([55.02978, 71.10144, 137.32585, 166.15111, 560.4914,
                  77.48594, 26.329714, 77.8307, 119.75101, 144.00725,
                  101.63227, 43.31267], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('x_w_l', DmapArray(name='x_w_l', value=np.array([-2.9401755, 145.45688, 230.3764, 84.676094, 451.35312,
                  75.04602, -1.385049, 85.661934, 62.407505, 131.11426,
                  11.158009, 42.414925], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('x_w_l_e', DmapArray(name='x_w_l_e', value=np.array([44.685745, 23.483494, 36.533936, 52.30831, 88.28202, 25.552269,
                  14.792147, 86.05524, 49.034096, 23.320967, 13.812058, 40.330265],
                  dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('x_w_s', DmapArray(name='x_w_s', value=np.array([17.663244, 181.19942, 274.58835, 220.84924, 631.99927,
                  130.5851, -22.957256, 181.46843, 171.9126, 213.20656,
                  61.037247, 139.12025], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('x_w_s_e', DmapArray(name='x_w_s_e', value=np.array([411.7451, 25.797867, 40.459, 80.37043, 120.65318,
                  32.736336, 74.18374, 64.1738, 42.973003, 43.801407,
                  51.02822, 45.003693], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('phi0', DmapArray(name='phi0', value=np.array([1.0006866, 2.4803083, 2.5298276, 2.3434021, 2.4804325, 2.5325048,
                  2.169191, 2.236938, 1.9520159, 1.4018124, 2.1937125, 1.0845904],
                  dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('phi0_e', DmapArray(name='phi0_e', value=np.array([0.5965372, 0.53425974, 0.73015106, 0.90231866, 1.1873266,
                  0.75273883, 0.35550907, 0.5863736, 1.0741612, 0.8912153,
                  1.0134457, 0.41260323], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('elv', DmapArray(name='elv', value=np.array([36.92941, 15.8056345, 16.163155, 14.772609, 15.8065405,
                  16.18226, 13.343854, 13.91679, 11.314536, 1.2040502,
                  13.554012, 37.19182], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('elv_low', DmapArray(name='elv_low', value=np.array([6.809374, 19.3193, 20.736443, 20.656742, 22.900055, 20.876936,
                  16.126497, 18.139124, 19.388645, 14.37398, 20.439638, 4.834197],
                  dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('elv_high', DmapArray(name='elv_high', value=np.array([35.00545, 11.25364, 9.640776, 3.2362866, 37.835796,
                  9.40011, 9.806536, 7.6573696, 36.541744, 35.356617,
                  37.48873, 35.88235], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('x_sd_l', DmapArray(name='x_sd_l', value=np.array([0.28318468, 0.26670623, 0.29874006, 0.24475327, 0.1948397,
                  0.3278357, 0.1807695, 0.4866734, 0.29503337, 0.12113429,
                  0.0754123, 0.24887906], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('x_sd_s', DmapArray(name='x_sd_s', value=np.array([0.28335696, 0.38254797, 0.45298725, 0.25643772, 0.32724318,
                  0.3764938, 0.18062629, 0.42809662, 0.24934997, 0.24624465,
                  0.07997479, 0.22335777], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12])),
                 ('x_sd_phi', DmapArray(name='x_sd_phi', value=np.array([0.78556406, 1.7383693, 2.2458427, 1.554859, 2.4740252,
                  1.9882897, 0.68696094, 1.1805041, 1.4410603, 1.7740515,
                  1.4178867, 0.5345671], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[12]))])]
