# Copyright (C) 2019 SuperDARN
# Author: Marina Schmidt
"""
Test data sets for DmapWrite
"""
import numpy as np

from collections import OrderedDict

from pydarn import DmapScalar, DmapArray

rawacf_data = [OrderedDict([('radar.revision.major',
                             DmapScalar(name='radar.revision.major', value=1,
                                        data_type=1, data_type_fmt='c')),
                            ('radar.revision.minor', DmapScalar(name='radar.revision.minor', value=18, data_type=1, data_type_fmt='c')),
                            ('origin.code', DmapScalar(name='origin.code', value=0, data_type=1, data_type_fmt='c')),
                            ('origin.time', DmapScalar(name='origin.time', value='Mon Apr 10 18:01:03 2017', data_type=9, data_type_fmt='s')),
                            ('origin.command', DmapScalar(name='origin.command', value='twofsound -fast -xcf 1 -p7', data_type=9, data_type_fmt='s')),
                            ('cp', DmapScalar(name='cp', value=3505, data_type=2, data_type_fmt='h')),
                            ('stid', DmapScalar(name='stid', value=5, data_type=2, data_type_fmt='h')),
                            ('time.yr', DmapScalar(name='time.yr', value=2017, data_type=2, data_type_fmt='h')),
                            ('time.mo', DmapScalar(name='time.mo', value=4, data_type=2, data_type_fmt='h')),
                            ('time.dy', DmapScalar(name='time.dy', value=10, data_type=2, data_type_fmt='h')),
                            ('time.hr', DmapScalar(name='time.hr', value=18, data_type=2, data_type_fmt='h')),
                            ('time.mt', DmapScalar(name='time.mt', value=1, data_type=2, data_type_fmt='h')),
                            ('time.sc', DmapScalar(name='time.sc', value=0, data_type=2, data_type_fmt='h')),
                            ('time.us', DmapScalar(name='time.us', value=35565, data_type=3, data_type_fmt='i')),
                            ('txpow', DmapScalar(name='txpow', value=9000, data_type=2, data_type_fmt='h')),
                            ('nave', DmapScalar(name='nave', value=32, data_type=2, data_type_fmt='h')),
                            ('atten', DmapScalar(name='atten', value=0, data_type=2, data_type_fmt='h')),
                            ('lagfr', DmapScalar(name='lagfr', value=1200, data_type=2, data_type_fmt='h')),
                            ('smsep', DmapScalar(name='smsep', value=300, data_type=2, data_type_fmt='h')),
                            ('ercod', DmapScalar(name='ercod', value=0, data_type=2, data_type_fmt='h')),
                            ('stat.agc', DmapScalar(name='stat.agc', value=0, data_type=2, data_type_fmt='h')),
                            ('stat.lopwr', DmapScalar(name='stat.lopwr', value=0, data_type=2, data_type_fmt='h')),
                            ('noise.search', DmapScalar(name='noise.search', value=27.822126388549805, data_type=4, data_type_fmt='f')),
                            ('noise.mean', DmapScalar(name='noise.mean', value=505125.4375, data_type=4, data_type_fmt='f')),
                            ('channel', DmapScalar(name='channel', value=2, data_type=2, data_type_fmt='h')),
                            ('bmnum', DmapScalar(name='bmnum', value=0, data_type=2, data_type_fmt='h')),
                            ('bmazm', DmapScalar(name='bmazm', value=-1.2000000476837158, data_type=4, data_type_fmt='f')),
                            ('scan', DmapScalar(name='scan', value=1, data_type=2, data_type_fmt='h')),
                            ('offset', DmapScalar(name='offset', value=0, data_type=2, data_type_fmt='h')),
                            ('rxrise', DmapScalar(name='rxrise', value=100, data_type=2, data_type_fmt='h')),
                            ('intt.sc', DmapScalar(name='intt.sc', value=3, data_type=2, data_type_fmt='h')),
                            ('intt.us', DmapScalar(name='intt.us', value=500000, data_type=3, data_type_fmt='i')),
                            ('txpl', DmapScalar(name='txpl', value=300, data_type=2, data_type_fmt='h')),
                            ('mpinc', DmapScalar(name='mpinc', value=2400, data_type=2, data_type_fmt='h')),
                            ('mppul', DmapScalar(name='mppul', value=7, data_type=2, data_type_fmt='h')),
                            ('mplgs', DmapScalar(name='mplgs', value=18, data_type=2, data_type_fmt='h')),
                            ('nrang', DmapScalar(name='nrang', value=75, data_type=2, data_type_fmt='h')),
                            ('frang', DmapScalar(name='frang', value=180, data_type=2, data_type_fmt='h')),
                            ('rsep', DmapScalar(name='rsep', value=45, data_type=2, data_type_fmt='h')),
                            ('xcf', DmapScalar(name='xcf', value=1, data_type=2, data_type_fmt='h')),
                            ('tfreq', DmapScalar(name='tfreq', value=13078, data_type=2, data_type_fmt='h')),
                            ('mxpwr', DmapScalar(name='mxpwr', value=1073741824, data_type=3, data_type_fmt='i')),
                            ('lvmax', DmapScalar(name='lvmax', value=20000, data_type=3, data_type_fmt='i')),
                            ('rawacf.revision.major', DmapScalar(name='rawacf.revision.major', value=0, data_type=3, data_type_fmt='i')),
                            ('rawacf.revision.minor', DmapScalar(name='rawacf.revision.minor', value=0, data_type=3, data_type_fmt='i')),
                            ('combf', DmapScalar(name='combf', value='$Id: twofsound.c,v 1.04 2016/11/08 20:00:00 KKrieger Exp $', data_type=9, data_type_fmt='s')),
                            ('thr', DmapScalar(name='thr', value=0.0, data_type=4, data_type_fmt='f')),
                            ('ptab', DmapArray(name='ptab', value=np.array([0, 9, 12, 20, 22, 26, 27], dtype=np.int16), data_type=2, data_type_fmt='h', dimension=1, shape=[7])),
                            ('ltab', DmapArray(name='ltab',
                                               value=np.array([0, 0, 26, 27,
                                                               20, 22, 9, 12,
                                                               22, 26, 22, 27,
                                                               20, 26, 20, 27,
                                                               12, 20, 0, 9,
                                                               12, 22, 9, 20,
                                                               0, 12, 9, 22,
                                                               12, 26, 12, 27,
                                                               9, 26, 9, 27,
                                                               27, 27],
                                                              dtype=np.int16),
                                               data_type=2, data_type_fmt='h',
                                               dimension=2, shape=[19, 2])),
                            ('slist',
                            DmapArray(name='slist', value=np.array([0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16,
                             17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33,
                             34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50,
                             51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
                             68, 69, 70, 71, 72, 73, 74], dtype=np.int16), data_type=2, data_type_fmt='h', dimension=1, shape=[75])),
                            ('pwr0', DmapArray(name='pwr0',
                             value=np.array([98.4375, 235.3125, 160.5, 59.1875, 43.65625,
                                             65.40625, 62.03125, 46.25, 72.84375, 60.0625,
                                             47.40625, 61.0625, 62.5625, 60.46875, 59.53125,
                                             42.84375, 39.78125, 40.9375, 51.6875, 55.125,
                                             37.03125, 56.15625, 51.71875, 50.40625, 58.46875,
                                             59.21875, 61.90625, 61.71875, 53.84375, 51.5625,
                                             55.4375, 38.8125, 93.09375, 279.8125, 267.59375,
                                             417.875, 1232.4062, 281.125, 126.3125, 60.65625,
                                             62.125, 118.5, 351.5625, 778.96875, 126.53125,
                                             151.46875, 82.21875, 86.625, 61.4375, 69.,
                                             92.71875, 61.15625, 72.0625, 77.84375, 49.84375,
                                             69.28125, 61.15625, 72.125, 69.125, 66.8125,
                                             59.625, 71.21875, 62.34375, 57.28125, 54.96875,
                                             52.65625, 61.84375, 56.34375, 75.875, 97.25,
                                             80.125, 44.5625, 52.53125, 81.40625, 86.03125],
                                            dtype=np.float32),
                                               data_type=4, data_type_fmt='f',
                                               dimension=1, shape=[75])),
                            ('acfd', DmapArray(name='acfd', value=np.array([98.4375, 0., 26.59375, -8.5, 28.90625, -3.5625],
                             dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[6])),
                            ('xcfd', DmapArray(name='xcfd', value=np.array([-11., 14.875, 0.84375, 2.375, 72.21875,
                             4.21875], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[6]))]),
               OrderedDict([('radar.revision.major', DmapScalar(name='radar.revision.major', value=1, data_type=1, data_type_fmt='c')),
                            ('radar.revision.minor', DmapScalar(name='radar.revision.minor', value=18, data_type=1, data_type_fmt='c')),
                            ('origin.code', DmapScalar(name='origin.code', value=0, data_type=1, data_type_fmt='c')),
                            ('origin.time', DmapScalar(name='origin.time', value='Mon Apr 10 18:01:20 2017', data_type=9, data_type_fmt='s')),
                            ('origin.command', DmapScalar(name='origin.command', value='twofsound -fast -xcf 1 -p7', data_type=9, data_type_fmt='s')),
                            ('cp', DmapScalar(name='cp', value=3505, data_type=2, data_type_fmt='h')),
                            ('stid', DmapScalar(name='stid', value=5, data_type=2, data_type_fmt='h')),
                            ('time.yr', DmapScalar(name='time.yr', value=2017, data_type=2, data_type_fmt='h')),
                            ('time.mo', DmapScalar(name='time.mo', value=4, data_type=2, data_type_fmt='h')),
                            ('time.dy', DmapScalar(name='time.dy', value=10, data_type=2, data_type_fmt='h')),
                            ('time.hr', DmapScalar(name='time.hr', value=18, data_type=2, data_type_fmt='h')),
                            ('time.mt', DmapScalar(name='time.mt', value=1, data_type=2, data_type_fmt='h')),
                            ('time.sc', DmapScalar(name='time.sc', value=17, data_type=2, data_type_fmt='h')),
                            ('time.us', DmapScalar(name='time.us', value=316927, data_type=3, data_type_fmt='i')),
                            ('txpow', DmapScalar(name='txpow', value=9000, data_type=2, data_type_fmt='h')),
                            ('nave', DmapScalar(name='nave', value=31, data_type=2, data_type_fmt='h')),
                            ('atten', DmapScalar(name='atten', value=0, data_type=2, data_type_fmt='h')),
                            ('lagfr', DmapScalar(name='lagfr', value=1200, data_type=2, data_type_fmt='h')),
                            ('smsep', DmapScalar(name='smsep', value=300, data_type=2, data_type_fmt='h')),
                            ('ercod', DmapScalar(name='ercod', value=0, data_type=2, data_type_fmt='h')),
                            ('stat.agc', DmapScalar(name='stat.agc', value=0, data_type=2, data_type_fmt='h')),
                            ('stat.lopwr', DmapScalar(name='stat.lopwr', value=0, data_type=2, data_type_fmt='h')),
                            ('noise.search', DmapScalar(name='noise.search', value=33.84693908691406, data_type=4, data_type_fmt='f')),
                            ('noise.mean', DmapScalar(name='noise.mean', value=505138.1875, data_type=4, data_type_fmt='f')),
                            ('channel', DmapScalar(name='channel', value=2, data_type=2, data_type_fmt='h')),
                            ('bmnum', DmapScalar(name='bmnum', value=5, data_type=2, data_type_fmt='h')),
                            ('bmazm', DmapScalar(name='bmazm', value=15.0, data_type=4, data_type_fmt='f')),
                            ('scan', DmapScalar(name='scan', value=0, data_type=2, data_type_fmt='h')),
                            ('offset', DmapScalar(name='offset', value=0, data_type=2, data_type_fmt='h')),
                            ('rxrise', DmapScalar(name='rxrise', value=100, data_type=2, data_type_fmt='h')),
                            ('intt.sc', DmapScalar(name='intt.sc', value=3, data_type=2, data_type_fmt='h')),
                            ('intt.us', DmapScalar(name='intt.us', value=500000, data_type=3, data_type_fmt='i')),
                            ('txpl', DmapScalar(name='txpl', value=300, data_type=2, data_type_fmt='h')),
                            ('mpinc', DmapScalar(name='mpinc', value=2400, data_type=2, data_type_fmt='h')),
                            ('mppul', DmapScalar(name='mppul', value=7, data_type=2, data_type_fmt='h')),
                            ('mplgs', DmapScalar(name='mplgs', value=18, data_type=2, data_type_fmt='h')),
                            ('nrang', DmapScalar(name='nrang', value=75, data_type=2, data_type_fmt='h')),
                            ('frang', DmapScalar(name='frang', value=180, data_type=2, data_type_fmt='h')),
                            ('rsep', DmapScalar(name='rsep', value=45, data_type=2, data_type_fmt='h')),
                            ('xcf', DmapScalar(name='xcf', value=1, data_type=2, data_type_fmt='h')),
                            ('tfreq', DmapScalar(name='tfreq', value=13274, data_type=2, data_type_fmt='h')),
                            ('mxpwr', DmapScalar(name='mxpwr', value=1073741824, data_type=3, data_type_fmt='i')),
                            ('lvmax', DmapScalar(name='lvmax', value=20000, data_type=3, data_type_fmt='i')),
                            ('rawacf.revision.major', DmapScalar(name='rawacf.revision.major', value=0, data_type=3, data_type_fmt='i')),
                            ('rawacf.revision.minor', DmapScalar(name='rawacf.revision.minor', value=0, data_type=3, data_type_fmt='i')),
                            ('combf', DmapScalar(name='combf', value='$Id: twofsound.c,v 1.04 2016/11/08 20:00:00 KKrieger Exp $', data_type=9, data_type_fmt='s')),
                            ('thr', DmapScalar(name='thr', value=0.0, data_type=4, data_type_fmt='f')),
                            ('ptab', DmapArray(name='ptab', value=np.array([0, 9, 12, 20, 22, 26, 27], dtype=np.int16), data_type=2, data_type_fmt='h', dimension=1, shape=[7])),
                            ('ltab', DmapArray(name='ltab', value=np.array([0, 0, 26, 27, 20, 22, 9, 12, 22, 26, 22, 27, 20, 26, 20, 27, 12,
                             20, 0, 9, 12, 22, 9, 20, 0, 12, 9, 22, 12, 26, 12, 27, 9, 26,
                             9, 27, 27, 27], dtype=np.int16), data_type=2, data_type_fmt='h', dimension=2, shape=[19, 2])),
                            ('slist', DmapArray(name='slist', value=np.array([0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16,
                             17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33,
                             34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50,
                             51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
                             68, 69, 70, 71, 72, 73, 74], dtype=np.int16), data_type=2, data_type_fmt='h', dimension=1, shape=[75])),
                            ('pwr0', DmapArray(name='pwr0', value=np.array([135.87097, 180.06451, 417.2258, 131.51613, 63.80645,
                             96.354836, 75.83871, 79.16129, 67.935486, 68.645164,
                             73.03226, 71.3871, 82.741936, 66.645164, 68.32258,
                             84.935486, 90.22581, 55.258064, 66.129036, 62.64516,
                             80.870964, 75.80645, 93.51613, 85.741936, 41.870968,
                             66.645164, 71.22581, 82.22581, 71.03226, 67.22581,
                             84.354836, 87.29032, 78.16129, 61.548386, 79.32258,
                             92.16129, 109.83871, 125.80645, 104.741936, 104.935486,
                             114., 115.48387, 79.129036, 95.58064, 90.70968,
                             86.22581, 141.87097, 108.129036, 68.96774, 70.3871,
                             115.16129, 76.16129, 68.96774, 99.90323, 69.354836,
                             82.935486, 102.645164, 97.48387, 75.935486, 58.419353,
                             99.29032, 90.548386, 64.58064, 70.741936, 75.96774,
                             70.96774, 73.354836, 102.064514, 86.258064, 149.3871,
                             161.90323, 92.58064, 59.64516, 76.70968, 120.29032],
                             dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[75])),
                            ('acfd', DmapArray(name='acfd', value=np.array([135.87096, 0., 18.612904, 6.677419,
                             0.6774193, -4.548387], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[6])),
                            ('xcfd', DmapArray(name='xcfd', value=np.array([36.51613, -12.16129, 16.870968, -29.032257, -41.580643,
                             -26.80645], dtype=np.float32), data_type=4,
                                               data_type_fmt='f', dimension=1,
                                               shape=[6]))]),
               OrderedDict([('radar.revision.major', DmapScalar(name='radar.revision.major', value=1, data_type=1, data_type_fmt='c')),
                            ('radar.revision.minor', DmapScalar(name='radar.revision.minor', value=18, data_type=1, data_type_fmt='c')),
                            ('origin.code', DmapScalar(name='origin.code', value=0, data_type=1, data_type_fmt='c')),
                            ('origin.time', DmapScalar(name='origin.time', value='Mon Apr 10 19:59:44 2017', data_type=9, data_type_fmt='s')),
                            ('origin.command', DmapScalar(name='origin.command', value='twofsound -fast -xcf 1 -p7', data_type=9, data_type_fmt='s')),
                            ('cp', DmapScalar(name='cp', value=3505, data_type=2, data_type_fmt='h')),
                            ('stid', DmapScalar(name='stid', value=5, data_type=2, data_type_fmt='h')),
                            ('time.yr', DmapScalar(name='time.yr', value=2017, data_type=2, data_type_fmt='h')),
                            ('time.mo', DmapScalar(name='time.mo', value=4, data_type=2, data_type_fmt='h')),
                            ('time.dy', DmapScalar(name='time.dy', value=10, data_type=2, data_type_fmt='h')),
                            ('time.hr', DmapScalar(name='time.hr', value=19, data_type=2, data_type_fmt='h')),
                            ('time.mt', DmapScalar(name='time.mt', value=59, data_type=2, data_type_fmt='h')),
                            ('time.sc', DmapScalar(name='time.sc', value=41, data_type=2, data_type_fmt='h')),
                            ('time.us', DmapScalar(name='time.us', value=453589, data_type=3, data_type_fmt='i')),
                            ('txpow', DmapScalar(name='txpow', value=9000, data_type=2, data_type_fmt='h')),
                            ('nave', DmapScalar(name='nave', value=31, data_type=2, data_type_fmt='h')),
                            ('atten', DmapScalar(name='atten', value=0, data_type=2, data_type_fmt='h')),
                            ('lagfr', DmapScalar(name='lagfr', value=1200, data_type=2, data_type_fmt='h')),
                            ('smsep', DmapScalar(name='smsep', value=300, data_type=2, data_type_fmt='h')),
                            ('ercod', DmapScalar(name='ercod', value=0, data_type=2, data_type_fmt='h')),
                            ('stat.agc', DmapScalar(name='stat.agc', value=0, data_type=2, data_type_fmt='h')),
                            ('stat.lopwr', DmapScalar(name='stat.lopwr', value=0, data_type=2, data_type_fmt='h')),
                            ('noise.search', DmapScalar(name='noise.search', value=39.8087272644043, data_type=4, data_type_fmt='f')),
                            ('noise.mean', DmapScalar(name='noise.mean', value=505139.1875, data_type=4, data_type_fmt='f')),
                            ('channel', DmapScalar(name='channel', value=2, data_type=2, data_type_fmt='h')),
                            ('bmnum', DmapScalar(name='bmnum', value=12, data_type=2, data_type_fmt='h')),
                            ('bmazm', DmapScalar(name='bmazm', value=37.68000030517578, data_type=4, data_type_fmt='f')),
                            ('scan', DmapScalar(name='scan', value=0, data_type=2, data_type_fmt='h')),
                            ('offset', DmapScalar(name='offset', value=0, data_type=2, data_type_fmt='h')),
                            ('rxrise', DmapScalar(name='rxrise', value=100, data_type=2, data_type_fmt='h')),
                            ('intt.sc', DmapScalar(name='intt.sc', value=3, data_type=2, data_type_fmt='h')),
                            ('intt.us', DmapScalar(name='intt.us', value=500000, data_type=3, data_type_fmt='i')),
                            ('txpl', DmapScalar(name='txpl', value=300, data_type=2, data_type_fmt='h')),
                            ('mpinc', DmapScalar(name='mpinc', value=2400, data_type=2, data_type_fmt='h')),
                            ('mppul', DmapScalar(name='mppul', value=7, data_type=2, data_type_fmt='h')),
                            ('mplgs', DmapScalar(name='mplgs', value=18, data_type=2, data_type_fmt='h')),
                            ('nrang', DmapScalar(name='nrang', value=75, data_type=2, data_type_fmt='h')),
                            ('frang', DmapScalar(name='frang', value=180, data_type=2, data_type_fmt='h')),
                            ('rsep', DmapScalar(name='rsep', value=45, data_type=2, data_type_fmt='h')),
                            ('xcf', DmapScalar(name='xcf', value=1, data_type=2, data_type_fmt='h')),
                            ('tfreq', DmapScalar(name='tfreq', value=13051, data_type=2, data_type_fmt='h')),
                            ('mxpwr', DmapScalar(name='mxpwr', value=1073741824, data_type=3, data_type_fmt='i')),
                            ('lvmax', DmapScalar(name='lvmax', value=20000, data_type=3, data_type_fmt='i')),
                            ('rawacf.revision.major', DmapScalar(name='rawacf.revision.major', value=0, data_type=3, data_type_fmt='i')),
                            ('rawacf.revision.minor', DmapScalar(name='rawacf.revision.minor', value=0, data_type=3, data_type_fmt='i')),
                            ('combf', DmapScalar(name='combf', value='$Id: twofsound.c,v 1.04 2016/11/08 20:00:00 KKrieger Exp $', data_type=9, data_type_fmt='s')),
                            ('thr', DmapScalar(name='thr', value=0.0, data_type=4, data_type_fmt='f')),
                            ('ptab', DmapArray(name='ptab', value=np.array([0, 9, 12, 20, 22, 26, 27], dtype=np.int16), data_type=2, data_type_fmt='h', dimension=1, shape=[7])),
                            ('ltab', DmapArray(name='ltab',
                                               value=np.array([0, 0, 26, 27, 20, 22,
                                                               9, 12, 22, 26, 22, 27,
                                                               20, 26, 20, 27, 12, 20,
                                                               0, 9, 12, 22, 9, 20,
                                                               0, 12, 9, 22, 12, 26,
                                                               12, 27, 9, 26, 9, 27,
                                                               27, 27],
                                                              dtype=np.int16),
                                               data_type=2, data_type_fmt='h',
                                               dimension=2, shape=[19, 2])),
                            ('slist', DmapArray(name='slist',
                                                value=np.array([0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16,
                                                                17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33,
                                                                34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50,
                                                                51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67,
                                                                68, 69, 70, 71, 72, 73, 74], dtype=np.int16),
                                                data_type=2, data_type_fmt='h',
                                                dimension=1, shape=[75])),
                            ('pwr0', DmapArray(name='pwr0',
                                               value=np.array([353.12903, 329.32257, 59.80645, 105.77419, 129.90323,
                                                               83.354836, 174.06451, 62.387096, 95.80645, 109.645164,
                                                               66.935486, 120.32258, 95.935486, 96.51613, 127.451614,
                                                               78.129036, 77.80645, 91.22581, 168., 98.32258,
                                                               167.12903, 78.41936, 133.2258, 108.451614, 140.70967,
                                                               44.580647, 127.3871, 122.77419, 77.451614, 108.48387,
                                                               69.41936, 119.32258, 113.96774, 79.29032, 116.645164,
                                                               153.3871, 94.3871, 146.80646, 139.45161, 127.,
                                                               196.19354, 146., 201.3871, 140.48387, 171.51613,
                                                               112.83871, 84.09677, 117.70968, 376.96774, 824.5161,
                                                               625.3226, 342.74194, 330.87097, 224.2258, 133.12903,
                                                               175., 79.48387, 97.645164, 198.48387, 350.96774,
                                                               587.9032, 589.0323, 299.25806, 142., 106.67742,
                                                               94.67742, 69.19355, 112.03226, 107.32258, 135.80646,
                                                               76.741936, 91.451614, 92.80645, 99.96774, 122.935486],
                                                              dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[75])),
                            ('acfd', DmapArray(name='acfd', value=np.array([353.12903, 0., 243.87096, 23.838709, -60.548386,
                             43.419353], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[6])),
                            ('xcfd', DmapArray(name='xcfd', value=np.array([77.70968, 234.38708, -25.419353, 18.354837,
                             -78.48387, -201.45161], dtype=np.float32), data_type=4, data_type_fmt='f', dimension=1, shape=[6]))])]
